@@ -1,6 +1,6 @@
 use anyhow::Result;
 
-use super::{Audit, audit_meta};
+use super::{Audit, AuditLoadError, audit_meta};
 use crate::finding::{Confidence, Finding, Severity};
 use crate::models::Workflow;
 use crate::state::AuditState;
@@ -14,7 +14,7 @@ audit_meta!(
 );
 
 impl Audit for DangerousTriggers {
-    fn new(_: AuditState) -> Result<Self> {
+    fn new(_state: &AuditState<'_>) -> Result<Self, AuditLoadError> {
         Ok(Self)
     }
 
