@@ -1,13 +1,12 @@
 use std::ops::Deref;
 
-use anyhow::Ok;
 use github_actions_models::{
     common::{EnvValue, Uses},
     workflow::job::StepBody,
 };
 use indexmap::IndexMap;
 
-use super::{Audit, audit_meta};
+use super::{Audit, AuditLoadError, audit_meta};
 use crate::{
     finding::{Confidence, Severity},
     models::uses::RepositoryUsesExt as _,
@@ -22,9 +21,7 @@ const KNOWN_PYTHON_TP_INDICES: &[&str] = &[
     "https://test.pypi.org/legacy/",
 ];
 
-pub(crate) struct UseTrustedPublishing {
-    pub(crate) _state: AuditState,
-}
+pub(crate) struct UseTrustedPublishing;
 
 audit_meta!(
     UseTrustedPublishing,
@@ -70,8 +67,8 @@ impl UseTrustedPublishing {
 }
 
 impl Audit for UseTrustedPublishing {
-    fn new(state: AuditState) -> anyhow::Result<Self> {
-        Ok(Self { _state: state })
+    fn new(_state: &AuditState<'_>) -> Result<Self, AuditLoadError> {
+        Ok(Self)
     }
 
     fn audit_step<'w>(&self, step: &super::Step<'w>) -> anyhow::Result<Vec<super::Finding<'w>>> {
