@@ -93,6 +93,20 @@ impl PartialEq<str> for Context<'_> {
     }
 }
 
+#[derive(Debug)]
+pub(crate) struct Function<'src>(pub(crate) &'src str);
+
+impl PartialEq for Function<'_> {
+    fn eq(&self, other: &Self) -> bool {
+        self.0.eq_ignore_ascii_case(other.0)
+    }
+}
+impl PartialEq<str> for Function<'_> {
+    fn eq(&self, other: &str) -> bool {
+        self.0.eq_ignore_ascii_case(other)
+    }
+}
+
 #[derive(Debug)]
 pub(crate) struct Identifier<'src>(&'src str);
 
@@ -140,7 +154,7 @@ pub(crate) enum Expr<'src> {
     Star,
     /// A function call.
     Call {
-        func: &'src str,
+        func: Function<'src>,
         args: Vec<Expr<'src>>,
     },
     /// A context identifier component, e.g. `github` in `github.actor`.
@@ -173,41 +187,48 @@ impl<'src> Expr<'src> {
         Self::Context(Context::new(r, components))
     }
 
-    /// Returns all of the contexts used in this expression, regardless
-    /// of dataflow.
+    /// Returns the contexts in this expression that directly flow into the
+    /// expression's evaluation.
     ///
-    /// **IMPORTANT**: This only returns "well-known" contexts, i.e. ones
-    /// that are defined at the top level. In other words, if an expression
-    /// contains both `foo.bar` and `foo().bar`, only the former will be
-    /// returned, as `foo()` can be anything and thus the `bar` access against
-    /// it has no particular meaning.
-    pub(crate) fn contexts(&self) -> Vec<&Context> {
+    /// For example `${{ foo.bar }}` returns `foo.bar` since the value
+    /// of `foo.bar` flows into the evaluation. On the other hand,
+    /// `${{ foo.bar == 'abc' }}` returns no expanded contexts,
+    /// since the value of `foo.bar` flows into a boolean evaluation
+    /// that gets expanded.
+    pub(crate) fn dataflow_contexts(&self) -> Vec<&Context> {
         let mut contexts = vec![];
 
         match self {
-            Expr::Call { func: _, args } => {
-                for arg in args {
-                    contexts.extend(arg.contexts());
+            Expr::Call { func, args } => {
+                // These functions, when evaluated, produce an evaluation
+                // that includes some or all of the contexts listed in
+                // their arguments.
+                if func == "toJSON" || func == "format" || func == "join" {
+                    for arg in args {
+                        contexts.extend(arg.dataflow_contexts());
+                    }
                 }
             }
-            Expr::Index(expr) => contexts.extend(expr.contexts()),
-            Expr::Context(ctx) => {
-                if matches!(ctx.components[0], Expr::Call { .. }) {
-                    // If the context looks something like `foo(args).a.b.c`, then
-                    // we need to check each of `args` for contexts but skip
-                    // the trailing identifiers, since those aren't well-known.
-                    contexts.extend(ctx.components[0].contexts());
-                } else {
-                    // Otherwise, if the context looks like a normal context,
-                    // we include it in its entirety.
-                    contexts.push(ctx)
+            // NOTE: We intentionally don't handle the `func(...).foo.bar`
+            // case differently here, since a call followed by a
+            // context access *can* flow into the evaluation.
+            // For example, `${{ fromJSON(something) }}` evaluates to
+            // `Object` but `${{ fromJSON(something).foo }}` evaluates
+            // to the contents of `something.foo`.
+            Expr::Context(ctx) => contexts.push(ctx),
+            Expr::BinOp { lhs, op, rhs } => match op {
+                // With && only the RHS can flow into the evaluation as a context
+                // (rather than a boolean).
+                BinOp::And => {
+                    contexts.extend(rhs.dataflow_contexts());
                 }
-            }
-            Expr::BinOp { lhs, op: _, rhs } => {
-                contexts.extend(lhs.contexts());
-                contexts.extend(rhs.contexts());
-            }
-            Expr::UnOp { op: _, expr } => contexts.extend(expr.contexts()),
+                // With || either the LHS or RHS can flow into the evaluation as a context.
+                BinOp::Or => {
+                    contexts.extend(lhs.dataflow_contexts());
+                    contexts.extend(rhs.dataflow_contexts());
+                }
+                _ => (),
+            },
             _ => (),
         }
 
@@ -351,7 +372,7 @@ impl<'src> Expr<'src> {
                         .collect::<Result<_, _>>()?;
 
                     Ok(Expr::Call {
-                        func: identifier.as_str(),
+                        func: Function(identifier.as_str()),
                         args,
                     }
                     .into())
@@ -391,11 +412,21 @@ mod tests {
     use pest::Parser as _;
     use pretty_assertions::assert_eq;
 
-    use super::{BinOp, Expr, ExprParser, Rule, UnOp};
+    use super::{BinOp, Context, Expr, ExprParser, Function, Rule, UnOp};
+
+    #[test]
+    fn test_function_eq() {
+        let func = Function("foo");
+        assert_eq!(&func, "foo");
+        assert_eq!(&func, "FOO");
+        assert_eq!(&func, "Foo");
+
+        assert_eq!(func, Function("FOO"));
+    }
 
     #[test]
     fn test_context_eq() {
-        let ctx = super::Context::try_from("foo.bar.baz").unwrap();
+        let ctx = Context::try_from("foo.bar.baz").unwrap();
         assert_eq!(&ctx, "foo.bar.baz");
         assert_eq!(&ctx, "FOO.BAR.BAZ");
         assert_eq!(&ctx, "Foo.Bar.Baz");
@@ -403,7 +434,7 @@ mod tests {
 
     #[test]
     fn test_context_child_of() {
-        let ctx = super::Context::try_from("foo.bar.baz").unwrap();
+        let ctx = Context::try_from("foo.bar.baz").unwrap();
 
         for (case, child) in &[
             // Trivial child cases.
@@ -432,7 +463,7 @@ mod tests {
 
     #[test]
     fn test_context_pop_if() {
-        let ctx = super::Context::try_from("foo.bar.baz").unwrap();
+        let ctx = Context::try_from("foo.bar.baz").unwrap();
 
         for (case, expected) in &[
             ("foo", Some("bar.baz")),
@@ -585,7 +616,7 @@ mod tests {
             (
                 "foo(1, 2, 3)",
                 Expr::Call {
-                    func: "foo",
+                    func: Function("foo"),
                     args: vec![Expr::Number(1.0), Expr::Number(2.0), Expr::Number(3.0)],
                 },
             ),
@@ -693,16 +724,41 @@ mod tests {
     }
 
     #[test]
-    fn test_expr_contexts() {
-        let expr = Expr::parse(
-            "foo.bar && abc && d.e.f && andThis(should.work).except.this && but().not.this",
-        )
-        .unwrap();
+    fn test_expr_dataflow_contexts() -> Result<()> {
+        // Trivial cases.
+        let expr = Expr::parse("foo.bar")?;
+        assert_eq!(expr.dataflow_contexts(), ["foo.bar"]);
 
-        assert_eq!(expr.contexts(), ["foo.bar", "abc", "d.e.f", "should.work"]);
+        let expr = Expr::parse("foo.bar[1]")?;
+        assert_eq!(expr.dataflow_contexts(), ["foo.bar[1]"]);
 
-        let expr = Expr::parse("fromJson(steps.runs.outputs.data).workflow_runs[0].id").unwrap();
+        // No dataflow due to a boolean expression.
+        let expr = Expr::parse("foo.bar == 'bar'")?;
+        assert!(expr.dataflow_contexts().is_empty());
 
-        assert_eq!(expr.contexts(), ["steps.runs.outputs.data"])
+        // ||: all contexts potentially expand into the evaluation.
+        let expr = Expr::parse("foo.bar || abc || d.e.f")?;
+        assert_eq!(expr.dataflow_contexts(), ["foo.bar", "abc", "d.e.f"]);
+
+        // &&: only the RHS context(s) expand into the evaluation.
+        let expr = Expr::parse("foo.bar && abc && d.e.f")?;
+        assert_eq!(expr.dataflow_contexts(), ["d.e.f"]);
+
+        let expr = Expr::parse("foo.bar == 'bar' && foo.bar || 'false'")?;
+        assert_eq!(expr.dataflow_contexts(), ["foo.bar"]);
+
+        let expr = Expr::parse("foo.bar == 'bar' && foo.bar || foo.baz")?;
+        assert_eq!(expr.dataflow_contexts(), ["foo.bar", "foo.baz"]);
+
+        let expr = Expr::parse("fromJson(steps.runs.outputs.data).workflow_runs[0].id")?;
+        assert_eq!(
+            expr.dataflow_contexts(),
+            ["fromJson(steps.runs.outputs.data).workflow_runs[0].id"]
+        );
+
+        let expr = Expr::parse("format('{0} {1} {2}', foo.bar, tojson(github), toJSON(github))")?;
+        assert_eq!(expr.dataflow_contexts(), ["foo.bar", "github", "github"]);
+
+        Ok(())
     }
 }
