@@ -180,3 +180,16 @@ fn issue_612_repro() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn invalid_config_file() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .output(OutputMode::Stderr)
+            .config("/dev/null")
+            .input(input_under_test("e2e-menagerie"))
+            .run()?
+    );
+
+    Ok(())
+}
